#####################################################################
### Analysis for "Location Probability Cueing: An Applied Version" ##
### written by Marian Sauter, October, 19th 2017 ####################
#####################################################################

# Set working directories and load libraries
setwd(dirname(rstudioapi::getActiveDocumentContext()$path))

#options(scipen=10000) # wissenschaftliche Notation abschalten
library(ez) # ezANOVA-Funktions
library(plyr) # ddply!!!
library(lsr) # cohensD
library(ggplot2) # plots
library(BayesFactor) # Bayes
library(stringr)

# Load helper functions
if(!exists("normDataWithin", mode="function")) source("http://www.mariansauter.de/files/R/r_functions.R")
if(!exists("summarySEwithin", mode="function")) source("http://www.mariansauter.de/files/R/r_functions.R")
if(!exists("article.ttest", mode="function")) source("http://www.mariansauter.de/files/R/r_functions_article.R")
if(!exists("article.ttest_full", mode="function")) source("http://www.mariansauter.de/files/R/r_functions_article.R")
if(!exists("article.ezANOVA", mode="function")) source("http://www.mariansauter.de/files/R/r_functions_article.R")

##### Blog: Analysis 1 - RT overall ##########################
agg <- ddply(gesamt, ~ subject, summarise, RTm = median(rt), Nt=length(rt))
(agg2 <- summarySEwithin(agg, measurevar="RTm", withinvars=NULL, idvar="subject"))

##############################################################
##### Blog: Analysis 2 - RT per distractor position ##########
agg <- ddply(gesamt, ~ subject + distractor_pos, summarise, RTm = median(rt), Nt=length(rt))
(agg2 <- summarySEwithin(agg, measurevar="RTm", withinvars=c("distractor_pos"), idvar="subject"))

##### Blog: Plot for distractor interference
colorder <- c( "0", "9", "1") 

(Plot <- ggplot(agg2, aes(x=distractor_pos, y=RTm)) + 
    geom_bar(stat="identity", position = position_dodge(width=0.9), fill="#09629e") +
    geom_errorbar(width=0.1,aes(ymax = RTm + se, ymin=RTm - se), position = position_dodge(width=0.9)) + 
    geom_text(aes(y=700, label=round(RTm)), position = position_dodge(width=0.9)) +
    theme_bw() + theme(text = element_text(size=20), panel.border = element_rect(size = 1.5), axis.title = element_text(vjust =1), plot.title = element_text(size=20, vjust=1), legend.position=c(0.38,0.9)) + 
    scale_x_discrete(limits=colorder, labels=c("distractor\nabsent","distractor in\nlikely area","distractor in\nunlikely area")) + 
    scale_y_continuous(breaks=c(800,850,900,950,1000,1050))+
    coord_cartesian(ylim=c(800, 1075))+
    labs(title = "", x="", y="Response time [ms]"))

##############################################################################
### Blog: T-tests
same_freq <- subset(gesamt, distractor_pos == "9")
same_rare <- subset(gesamt, distractor_pos == "1")
same_absent <- subset(gesamt, distractor_pos == "0")
same_present <- subset(gesamt, distractor_pos != "0")

agg_freq <- ddply(same_freq, ~ subject, summarise, RTm = median(rt))
agg_rare <- ddply(same_rare, ~ subject, summarise, RTm = median(rt))
agg_absent <- ddply(same_absent, ~ subject, summarise, RTm = median(rt))
agg_present <- ddply(same_present, ~ subject, summarise, RTm = median(rt))

# First comparison: present RTs vs. absent RTs
mean(agg_present$RTm)
mean(agg_absent$RTm)
(ttest = t.test(agg_present$RTm, agg_absent$RTm, paired=TRUE))
d <- cohensD(agg_present$RTm, agg_absent$RTm, method = "paired")
(BF = ttestBF(agg_present$RTm, agg_absent$RTm, paired=TRUE))
BFsamples <- posterior(BF, iterations = 1000)
HPDinterval(BFsamples)

mean(agg_present$RTm)
mean(agg_absent$RTm)
article.ttest_full(ttest, d, BF)

# Second comparison: frequent RTs vs. rare RTs
mean(agg_freq$RTm)
mean(agg_rare$RTm)
(ttest = t.test(agg_freq$RTm, agg_rare$RTm, paired=TRUE))
cohensD(agg_freq$RTm, agg_rare$RTm, method = "paired")
(BF = ttestBF(agg_freq$RTm, agg_rare$RTm, paired=TRUE, nullInterval=c(-Inf,0)))
BFsamples <- posterior(BF, 1,iterations = 1000)
HPDinterval(BFsamples)

article.ttest_full(ttest, d, BF[1])
